package logic

import (
	"fusenapi/model/gmodel"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"
	"time"

	"context"

	"fusenapi/server/info/internal/svc"
	"fusenapi/server/info/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type ContactUsLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewContactUsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *ContactUsLogic {
	return &ContactUsLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *ContactUsLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *ContactUsLogic) ContactUs(req *types.ContactUsRequest, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null

	if !auth.ValidateEmail(req.Email) {
		return resp.SetStatusWithMessage(basic.CodeRequestParamsErr, "email format error")
	}

	if req.Message == "" {
		return resp.SetStatusWithMessage(basic.CodeRequestParamsErr, "remarks must exist")
	}

	now := time.Now().UTC()
	err := l.svcCtx.AllModels.FsContact.Save(l.ctx, &gmodel.FsContact{
		Name:    &req.Name,
		Email:   &req.Email,
		Phone:   &req.Phone,
		Message: &req.Message,
		Status:  gmodel.FsInt64(0),
		Ctime:   &now,
	})
	if err != nil {
		return resp.SetStatusWithMessage(basic.CodeRequestParamsErr, err.Error())
	}

	return resp.SetStatus(basic.CodeOK)
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *ContactUsLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
