package logic

import (
	"fusenapi/constants"
	"fusenapi/service/repositories"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"context"

	"fusenapi/server/order/internal/svc"
	"fusenapi/server/order/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type CreatePrePaymentByDepositLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewCreatePrePaymentByDepositLogic(ctx context.Context, svcCtx *svc.ServiceContext) *CreatePrePaymentByDepositLogic {
	return &CreatePrePaymentByDepositLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *CreatePrePaymentByDepositLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *CreatePrePaymentByDepositLogic) CreatePrePaymentByDeposit(req *types.CreatePrePaymentByDepositReq, userinfo *auth.UserInfo) (resp *basic.Response) {
	// 返回值必须调用Set重新返回, resp可以空指针调用 resp.SetStatus(basic.CodeOK, data)
	// userinfo 传入值时, 一定不为null
	if !userinfo.IsUser() {
		// 如果是，返回未授权的错误码
		return resp.SetStatus(basic.CodeUnAuth)
	}
	if req.DeliveryMethod == constants.DELIVERYMETHODDIRECTMAIL {
		if req.DeliveryAddress == nil {
			return resp.SetStatus(basic.CodeErrOrderCreatePrePaymentParam)
		} else {
			if req.DeliveryAddress.Street == "" ||
				req.DeliveryAddress.City == "" ||
				req.DeliveryAddress.Mobile == "" ||
				req.DeliveryAddress.State == "" ||
				req.DeliveryAddress.Suite == "" ||
				req.DeliveryAddress.ZipCode == "" ||
				req.DeliveryAddress.LastName == "" ||
				req.DeliveryAddress.FirstName == "" {
				return resp.SetStatus(basic.CodeErrOrderCreatePrePaymentParam)
			}
		}
	}
	var orderAddress repositories.OrderAddress
	if req.DeliveryAddress != nil {
		orderAddress.Street = req.DeliveryAddress.Street
		orderAddress.City = req.DeliveryAddress.City
		orderAddress.FirstName = req.DeliveryAddress.FirstName
		orderAddress.LastName = req.DeliveryAddress.LastName
		orderAddress.Mobile = req.DeliveryAddress.Mobile
		orderAddress.State = req.DeliveryAddress.State
		orderAddress.Suite = req.DeliveryAddress.Suite
		orderAddress.ZipCode = req.DeliveryAddress.ZipCode
	}
	res, err := l.svcCtx.Repositories.NewOrder.CreatePrePaymentByDeposit(l.ctx, &repositories.CreatePrePaymentByDepositReq{
		UserId:          userinfo.UserId,
		OrderSn:         req.OrderSn,
		DeliveryMethod:  req.DeliveryMethod,
		DeliveryAddress: &orderAddress,
		Country:         "US",
		Currency:        "usd",
		StripeKey:       l.svcCtx.Config.PayConfig.Stripe.Key,
	})

	if err != nil {
		return resp.SetStatus(&res.ErrorCode)
	}

	return resp.SetStatus(basic.CodeOK, map[string]interface{}{
		"order_detail": res.OrderDetail,
		"order_pay":    res.OrderPay,
	})
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *CreatePrePaymentByDepositLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
